# This file has been generated


build_system = 'GitHub Actions'
build_id = '1780240375'
build_number = '257'
build_version = None
job_id = '1780240375_257'
job_url = 'https://github.com/epcpower/pm/actions/runs/1780240375'
